from config import get_config
from ffmpegcmd import ffmpeg
import os, shutil, time


conf = get_config()


def reset_workdir(workdir: str):
    try:
        shutil.rmtree(workdir)
    except:
        print("workdir remove error")

    try:
        os.mkdir(workdir)
    except:
        print("workdir create error")

    print("Workdir Cleared")


def videofile_test(file: str) -> bool:
    if file.endswith(".mkv") or file.endswith(".avi") or file.endswith(".mp4"):
        return True
    else:
        return False


def copy_file(source: str, destination: str):
    if os.path.exists(f"{destination}.filepart"):
        os.remove(f"{destination}.filepart")

    try:
        shutil.copy(source, f"{destination}.filepart")
        os.rename(f"{destination}.filepart", destination)
    except:
        time.sleep(10)
        copy_file(source=source, destination=destination)


def process_file(source_dir: str, file: str):
    outputdir = source_dir.replace(conf.sourcedir, conf.outputdir)
    av1file = f"AV1_{file}"

    if not os.path.exists(outputdir):
        os.makedirs(outputdir)  # create dir if not exist

    if os.path.exists(os.path.join(outputdir, file)):
        print("Output File Exist --> Skipping")
        return False

    if videofile_test(file=file):
        print(
            f"Move video file: {os.path.join(source_dir,file)} --> {os.path.join(conf.workdir, file)}"
        )
        copy_file(os.path.join(source_dir, file), os.path.join(conf.workdir, file))

        print(f"Start transcode File: {file} --> {av1file}")
        ffmpeg(
            ffmpeg=conf.ffmpeg,
            params=conf.ffmpeg_params,
            source_file=os.path.join(conf.workdir, file),
            output_file=os.path.join(conf.workdir, av1file),
        )

        print(
            f"Move video file: {os.path.join(conf.workdir, av1file)} --> {os.path.join(outputdir, file)}"
        )
        copy_file(os.path.join(conf.workdir, av1file), os.path.join(outputdir, file))

        os.remove(os.path.join(conf.workdir, av1file))
        os.remove(os.path.join(conf.workdir, file))
        return True
    else:
        print(
            f"Move non video file: {os.path.join(source_dir, file)} --> {os.path.join(outputdir, file)}"
        )
        copy_file(os.path.join(source_dir, file), os.path.join(outputdir, file))
        return False


reset_workdir(workdir=conf.workdir)

for root, _, files in os.walk(conf.sourcedir):
    for file in files:
        print("--------------------")
        print(f"Process file: {os.path.join(root, file)}")
        if process_file(root, file):
            print("Waiting for terminate script")
            time.sleep(10)  # testing sleep for stop script time
            print("End of waiting for terminating script --> Continuing")
